function y = ATmult(P,x,M,N)
% ATMULT Matrix-vector product y = A^T * x via 2D convolution.
%
% y = ATmult(P,x,M,N)
%
% Computes the matrix-vector product y = A^Tx, where A = kron(A_r, A_c),
% equivalently Y = A_c^T * X^T * A_r, y = Y(:), where X = reshape(x,M,N).
% The colums and rows linear combinations of X, realized A_c, A_r, resp.,
% here computed via 2D convolution of X and the up-down and left-right 
% flipped point-spread-function P.
%
% See also AMULT, PSFGAUSS, FLIPUP, FLIPLR

% Reference: 
%
% P. C. Hansen, J. Nagy, D. O'Leary -- Deblurring Images: Matrices, 
% Spectra, and Filtering, SIAM, 2006.

% Per Christian Hansen, IMM, April 2009.  

X = reshape(x,M,N);
P = flipud(fliplr(P));
Y = conv2(X,P,'same');
y = Y(:);