function y = Amult(P,x,M,N)
% AMULT Matrix-vector product y = A * x via 2D convolution.
%
% y = Amult(P,x,M,N)
%
% Computes the matrix-vector product y = Ax, where A = kron(A_r, A_c),
% equivalently Y = A_c * X * A_r^T, y = Y(:), where X = reshape(x,M,N).
% The colums and rows linear combinations of X, realized by A_c, A_r, resp.,
% are computed via 2D convolution of X and the point-spread-function P.
%
% See also ATMULT, PSFGAUSS

% Reference: 
%
% P. C. Hansen, J. Nagy, D. O'Leary -- Deblurring Images: Matrices, 
% Spectra, and Filtering, SIAM, 2006.

% Per Christian Hansen, IMM, April 2009.  

X = reshape(x,M,N);
Y = conv2(X,P,'same');
y = Y(:);